﻿#region License Informtion
/* This program simulates objects path of motion.
 * Copyright (C) 2010  Timothy Eck II
 * 
 * Physics Simulator is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; version 2 of the License.
 * 
 * Physics Simulator is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.*/
#endregion
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace PhysicsSimulator.Engine
{
    /// <summary>
    /// This class represents a two dimensional force.
    /// </summary>
    class Force2
    {
        private Vector2 _acceleration;
        private bool _active;
        private string _name;
        private Vector2 _affectedArea;
        private bool _worldForce;

        #region Properties
        /// <summary>
        /// Gets or sets the acceleration of the force.
        /// </summary>
        /// <value>The acceleration of the force.</value>
        public Vector2 Acceleration
        {
            get { return _acceleration; }
            set { _acceleration = value; }
        }

        /// <summary>
        /// Gets or sets the area affected by the force. The x-value corresponds to the start of the
        /// force area and the y-value corresponds to the end of the area.
        /// </summary>
        /// <value>The area affected by the force.</value>
        public Vector2 AffectedArea
        {
            get { return _affectedArea; }
            set { _affectedArea = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether this <see cref="Force2"/> is active.
        /// </summary>
        /// <value><c>true</c> if active; otherwise, <c>false</c>.</value>
        public bool Active
        {
            get { return _active; }
            set { _active = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether the force is felt through out the world.
        /// </summary>
        /// <value><c>true</c> if the force is felt by objects through out the world; otherwise, <c>false</c>.</value>
        public bool WorldForce
        {
            get { return _worldForce; }
            set { _worldForce = value; }
        }

        /// <summary>
        /// Gets or sets the name of the force.
        /// </summary>
        /// <value>The name of the force.</value>
        public string Name
        {
            get { return _name; }
            set { _name = value; }
        }
        #endregion 

        /// <summary>
        /// Initializes a new instance of the <see cref="Force2"/> class.
        /// </summary>
        /// <param name="Name">The name of the force.</param>
        /// <param name="Active">If set to <c>true</c> then the force is activated.</param>
        /// <param name="WorldForce">If set to <c>true</c> then the force is set as a world force.</param>
        /// <param name="Acceleration">The acceleration of the force.</param>
        /// <param name="AffectedArea">The area affected of the force.</param>
        public Force2(string Name = "Name me please :'(", bool Active = false, bool WorldForce = true,
            Vector2 Acceleration = new Vector2(), Vector2 AffectedArea = new Vector2())
        {
            _name = Name;
            _active = Active;
            _worldForce = WorldForce;

            if (Acceleration == null)
            { 
                _acceleration = new Vector2();
            }
            else
            {
                _acceleration = Acceleration;
            }

            if (AffectedArea == null)
            {
                _affectedArea = new Vector2();
            }
            else
            {
                _affectedArea = AffectedArea;
            }
        }        
    }
}
