﻿#region License Informtion
/* This program simulates objects path of motion.
 * Copyright (C) 2010  Timothy Eck II
 * 
 * Physics Simulator is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; version 2 of the License.
 * 
 * Physics Simulator is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.*/
#endregion
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace PhysicsSimulator.Engine
{
    /// <summary>
    /// Represents a real object in two dimensional space.
    /// </summary>
    class PhysicsObject2
    {
        private Vector2 _position;
        private Vector2 _oldPosition;
        private Vector2 _velocity;
        private Vector2 _oldVelocity;
        private double _mass;
        private string _name;
        private bool _alive;

        #region Properties
        /// <summary>
        /// Gets or sets the old position.
        /// </summary>
        /// <value>The old position.</value>
        public Vector2 OldPosition
        {
            get { return _oldPosition; }
            set { _oldPosition = value; }
        }

        /// <summary>
        /// Gets or sets the old velocity.
        /// </summary>
        /// <value>The old velocity.</value>
        public Vector2 OldVelocity
        {
            get { return _oldVelocity; }
            set { _oldVelocity = value; }
        }

        /// <summary>
        /// Gets or sets the position of the object.
        /// </summary>
        /// <value>The position of the object.</value>
        public Vector2 Position
        {
            get { return _position; }
            set { _position = value; }
        }

        /// <summary>
        /// Gets or sets the velocity of the object.
        /// </summary>
        /// <value>The velocity of the object.</value>
        public Vector2 Velocity
        {
            get { return _velocity; }
            set { _velocity = value; }
        }

        /// <summary>
        /// Gets or sets the mass of the object.
        /// </summary>
        /// <value>The mass of the object.</value>
        public double Mass
        {
            get { return _mass; }
            set { _mass = value; }
        }

        /// <summary>
        /// Gets or sets the name of the object.
        /// </summary>
        /// <value>The name of the object.</value>
        public string Name
        {
            get { return _name; }
            set { _name = value; }
        }

        public bool Alive
        {
            get { return _alive; }
            set { _alive = value; }
        }
        #endregion

        /// <summary>
        /// Initializes a new instance of the <see cref="PhysicsObject2"/> class.
        /// </summary>
        /// <param name="Name">The name of the object.</param>
        /// <param name="Position">The position of the object.</param>
        /// <param name="Velocity">The velocity of the object.</param>
        /// <param name="Mass">The mass of the object.</param>
        public PhysicsObject2(string Name = "Please name me :'(", Vector2 Position = new Vector2(),
            Vector2 Velocity = new Vector2(), double Mass = 0, bool Alive = true)
        {
            _name = Name;

            if (Position == null)
            {
                _position = new Vector2();
            }
            else
            {
                _position = Position;
            }

            if (Velocity == null) { _velocity = new Vector2(); }
            else
            {
                _velocity = Velocity;
            }

            _oldPosition = new Vector2();
            _oldVelocity = new Vector2();

            _mass = Mass;
            _alive = Alive;
        }
    }
}

