﻿#region License Informtion
/* This program simulates objects path of motion.
 * Copyright (C) 2010  Timothy Eck II
 * 
 * Physics Simulator is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; version 2 of the License.
 * 
 * Physics Simulator is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.*/
#endregion
using System;
using System.Collections.Generic;
using PhysicsSimulator.Reports;

namespace PhysicsSimulator.Engine
{
	/// <summary>
	/// This struct contains the structure for the settings used to set up a simulation
	/// </summary>
    struct SimulationSettings
    {
        List<Force2> _forces;
        List<PhysicsObject2> _objects;
        List<Report> _reports;

        KillCondition _kill;

        float _stepValue;
        string _filePath;

        bool _runInLightMode;


        #region Properties
        /// <summary>
        /// Gets or sets the forces that are present in the simulation.
        /// </summary>
        /// <value>The forces in the simulation.</value>
        public List<Force2> Force
        {
            get { return _forces; }
            set { _forces = value; }
        }

        /// <summary>
        /// Gets or sets the objects  that will be involved in the simulation.
        /// </summary>
        /// <value>The objects in the simulation.</value>
        public List<PhysicsObject2> Objects
        {
            get { return _objects; }
            set { _objects = value; }
        }

        /// <summary>
        /// Gets or sets the kill condition.
        /// </summary>
        /// <value>The kill condition.</value>
        public KillCondition Kill
        {
            get { return _kill; }
            set { _kill = value; }
        }

        /// <summary>
        /// Gets or sets the file path.
        /// </summary>
        /// <value>The file path.</value>
        public string FilePath
        {
            get { return _filePath; }
            set { _filePath = value; }
        }

        /// <summary>
        /// Gets or sets the step value.
        /// </summary>
        /// <value>The step value.</value>
        public float StepValue
        {
            get { return _stepValue; }
            set { _stepValue = value; }
        }

        /// <summary>
        /// Gets or sets the reports.
        /// </summary>
        /// <value>The reports.</value>
        public List<Report> Reports
        {
            get { return _reports; }
            set { _reports = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether to [run in light mode].
        /// </summary>
        /// <value><c>true</c> if [run in light mode]; otherwise, <c>false</c>.</value>
        public bool RunInLightMode
        {
            get { return _runInLightMode; }
            set { _runInLightMode = value; }
        }
        #endregion

        /// <summary>
        /// Initializes a new instance of the <see cref="SimulationSettings"/> class.
        /// </summary>
        /// <param name="Forces">The forces in the simulation.</param>
        /// <param name="Objects">The objects in the simulation.</param>
        /// <param name="KillCondition">The kill condition for the simulation.</param>
        /// <param name="StepValue">The value to step by.</param>
        /// <param name="FilePath">The file path to save the results to.</param>
        public SimulationSettings(List<Force2> Forces, List<PhysicsObject2> Objects, KillCondition KillCondition,
            List<Report> Reports, float StepValue = 1f, string FilePath = "N/A", bool RunInLightMode = true)
        {
            _forces = Forces;
            _objects = Objects;
            _kill = KillCondition;
            _stepValue = StepValue;
            _filePath = FilePath;
            _reports = Reports;
            _runInLightMode = RunInLightMode;
        }
    }
}
