﻿#region License Informtion
/* This program simulates objects path of motion.
 * Copyright (C) 2010  Timothy Eck II
 * 
 * Physics Simulator is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; version 2 of the License.
 * 
 * Physics Simulator is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.*/
#endregion
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using PhysicsSimulator.Engine;

namespace PhysicsSimulator
{
    public partial class MainForm : Form
    {
        private List<Engine.Force2> _forces;
        private List<Engine.PhysicsObject2> _objects;
        private List<Reports.ReportSettings> _reports;

        private Engine.Force2 activeForce;
        private Engine.PhysicsObject2 activeObject;
        private Reports.ReportSettings activeReport;

        public MainForm()
        {
            InitializeComponent();

            _forces = new List<Engine.Force2>();
            _objects = new List<Engine.PhysicsObject2>();
            _reports = new List<Reports.ReportSettings>();

            activeForce = new Engine.Force2();
            activeObject = new Engine.PhysicsObject2();
            activeReport = new Reports.ReportSettings();
        }

        private void MainForm_Load(object sender, EventArgs e)
        {
            /*Sets up the settings page*/
            realtimeElapseTime.Enabled = false;
            simulationElapseTime.Enabled = false;
            vkXTextBox.Enabled = false;
            vkYTextBox.Enabled = false;
            pkXTextBox.Enabled = false;
            pkYTextBox.Enabled = false;
            xAxisTextBox.Enabled = false;
            yAxisTextBox.Enabled = false;
            
        }

        #region Object Tab methods
        private void addObjectButton_Click(object sender, EventArgs e)
        {
            AddObjectForm tempForm = new AddObjectForm();
            tempForm.ShowDialog(this, new Delegates.modifySimSettings(AddObject));
        }

        private void AddObject(object objectToAdd)
        {
            Engine.PhysicsObject2 newObject = (Engine.PhysicsObject2)objectToAdd;

            foreach (Engine.PhysicsObject2 pObject in _objects)
            {
                if (pObject.Name == newObject.Name)
                    newObject.Name += "_1";
            }

            _objects.Add(newObject);

            UpdateObjectList();
        }

        private void UpdateObjectList()
        {
            List<string> objectNameList = new List<string>();

            foreach (Engine.PhysicsObject2 pObject in _objects)
            {
                objectNameList.Add(pObject.Name);
            }

            objectsListBox.Items.Clear();
            objectsListBox.Items.AddRange(objectNameList.ToArray());

            killObjectListBox.Items.Clear();
            killObjectListBox.Items.AddRange(objectNameList.ToArray());
        }

        private void objectsListBox_SelectedIndexChanged(object sender, EventArgs e)
        {

            string objectName = (string)objectsListBox.SelectedItem;

            Engine.PhysicsObject2 pObject = new Engine.PhysicsObject2();

            for (int i = 0; i < _objects.Count; i++)
            {
                if (_objects[i].Name == objectName)
                    pObject = _objects[i];
                else if (_objects[i].Name == activeObject.Name)
                    _objects[i] = activeObject;
            }

            activeObject = pObject;

            objectNameTextBox.Text = objectName;
            objectMassTextBox.Text = pObject.Mass.ToString();
            objectAliveCheckBox.Checked = pObject.Alive;
            objectXPositionTextBox.Text = pObject.Position.XValue.ToString();
            objectYPositionTextBox.Text = pObject.Position.YValue.ToString();
            objectXVelocityTextBox.Text = pObject.Velocity.XValue.ToString();
            objectYVelocityTextBox.Text = pObject.Velocity.YValue.ToString();
        }

        private void deleteObjectButton_Click(object sender, EventArgs e)
        {
            List<Engine.PhysicsObject2> tempObject = new List<Engine.PhysicsObject2>();

            for (int i = 0; i < _objects.Count; i++)
            {
                if (_objects[i].Name != objectsListBox.SelectedItem.ToString())
                    tempObject.Add(_objects[i]);
            }

            _objects = tempObject;

            UpdateObjectList();
        }

        private void objectNameTextBox_TextChanged(object sender, EventArgs e)
        {
            string oldName = activeObject.Name;
            activeObject.Name = objectNameTextBox.Text;
            for (int i = 0; i < _objects.Count; i++)
            {
                if (_objects[i].Name == oldName)
                    _objects[i] = activeObject;
            }

            UpdateObjectList();
        }

        private void objectXPositionTextBox_TextChanged(object sender, EventArgs e)
        {
            double tempValue;
            if (!double.TryParse(objectXPositionTextBox.Text, out tempValue))
            {
                objectXPositionTextBox.Text = activeObject.Position.XValue.ToString();
            }
            else
            {
                Vector2 tempVector = new Vector2();
                tempVector.YValue = activeObject.Position.YValue;
                tempVector.XValue = tempValue;
                activeObject.Position = tempVector;
            }
        }

        private void objectYPositionTextBox_TextChanged(object sender, EventArgs e)
        {
            double tempValue;
            if (!double.TryParse(objectYPositionTextBox.Text, out tempValue))
            {
                objectYPositionTextBox.Text = activeObject.Position.YValue.ToString();
            }
            else
            {
                Vector2 tempVector = new Vector2();
                tempVector.XValue = activeObject.Position.XValue;
                tempVector.YValue = tempValue;
                activeObject.Position = tempVector;
            }
        }

        private void objectMassTextBox_TextChanged(object sender, EventArgs e)
        {
            double tempValue;
            if (!double.TryParse(objectMassTextBox.Text, out tempValue))
            {
                objectMassTextBox.Text = activeObject.Mass.ToString();
            }
            else
            {
                if (tempValue <= 0)
                    objectMassTextBox.Text = activeObject.Mass.ToString();
                else
                    activeObject.Mass = tempValue;
            }
        }

        private void objectXVelocityTextBox_TextChanged(object sender, EventArgs e)
        {
            double tempValue;
            if (!double.TryParse(objectXVelocityTextBox.Text, out tempValue))
            {
                objectXVelocityTextBox.Text = activeObject.Velocity.XValue.ToString();
            }
            else
            {
                Vector2 tempVector = new Vector2();
                tempVector.YValue = activeObject.Velocity.YValue;
                tempVector.XValue = tempValue;
                activeObject.Velocity = tempVector;
            }
        }

        private void objectYVelocityTextBox_TextChanged(object sender, EventArgs e)
        {
            double tempValue;
            if (!double.TryParse(objectYVelocityTextBox.Text, out tempValue))
            {
                objectYVelocityTextBox.Text = activeObject.Velocity.YValue.ToString();
            }
            else
            {
                Vector2 tempVector = new Vector2();
                tempVector.XValue = activeObject.Velocity.XValue;
                tempVector.YValue = tempValue;
                activeObject.Velocity = tempVector;
            }
        }

        private void objectAliveCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            activeObject.Alive = objectAliveCheckBox.Checked;
        }
        #endregion

        #region Force Tab methods
        private void addForceButton_Click(object sender, EventArgs e)
        {
            AddForceForm tempForm = new AddForceForm();
            tempForm.ShowDialog(this, new Delegates.modifySimSettings(AddForce));
        }

        private void AddForce(object forceToAdd)
        {
            Engine.Force2 newForce = (Engine.Force2)forceToAdd;

            foreach (Engine.Force2 force in _forces)
            {
                if (force.Name == newForce.Name)
                    newForce.Name += "_1";
            }

            _forces.Add(newForce);

            UpdateForceList();
        }

        private void UpdateForceList()
        {
            List<string> forceNameList = new List<string>();

            foreach (Engine.Force2 force in _forces)
            {
                forceNameList.Add(force.Name);
            }

            forceListBox.Items.Clear();
            forceListBox.Items.AddRange(forceNameList.ToArray());
        }

        private void forceListBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            Engine.Force2 force = new Engine.Force2();

            for (int i = 0; i < _forces.Count; i++)
            {
                if (_forces[i].Name == forceListBox.SelectedItem.ToString())
                    force = _forces[i];
                else if (_forces[i].Name == activeForce.Name)
                    _forces[i] = activeForce;
            }

            activeForce = force;

            forceNameTextBox.Text = force.Name;
            activeCheckBox.Checked = force.Active;
            worldForceCheckBox.Checked = force.WorldForce;
            xAccelerationTextBox.Text = force.Acceleration.XValue.ToString();
            yAccelerationTextBox.Text = force.Acceleration.YValue.ToString();
            beggingTextBox.Text = force.AffectedArea.XValue.ToString();
            endTextBox.Text = force.AffectedArea.YValue.ToString();
        }

        private void forceNameTextBox_TextChanged(object sender, EventArgs e)
        {
            string oldName = activeForce.Name;
            activeForce.Name = forceNameTextBox.Text;

            for (int i = 0; i < _forces.Count; i++)
            {
                if (_forces[i].Name == oldName)
                {
                    _forces[i] = activeForce;
                }
            }

            UpdateForceList();
        }

        private void xAccelerationTextBox_TextChanged(object sender, EventArgs e)
        {
            double tempValue;
            if (!double.TryParse(xAccelerationTextBox.Text, out tempValue))
            {
                xAccelerationTextBox.Text = activeForce.Acceleration.XValue.ToString();
            }
            else
            {
                Vector2 tempVector = new Vector2();
                tempVector.YValue = activeForce.Acceleration.YValue;
                tempVector.XValue = tempValue;
                activeForce.Acceleration = tempVector;
            }
        }

        private void yAccelerationTextBox_TextChanged(object sender, EventArgs e)
        {
            double tempValue;
            if (!double.TryParse(yAccelerationTextBox.Text, out tempValue))
            {
                yAccelerationTextBox.Text = activeForce.Acceleration.YValue.ToString();
            }
            else
            {
                Vector2 tempVector = new Vector2();
                tempVector.XValue = activeForce.Acceleration.XValue;
                tempVector.YValue = tempValue;
                activeForce.Acceleration = tempVector;
            }
        }

        private void beggingTextBox_TextChanged(object sender, EventArgs e)
        {
            double tempValue;
            if (!double.TryParse(beggingTextBox.Text, out tempValue))
            {
                beggingTextBox.Text = activeForce.AffectedArea.XValue.ToString();
            }
            else
            {
                Vector2 tempVector = new Vector2();
                tempVector.YValue = activeForce.AffectedArea.YValue;
                tempVector.XValue = tempValue;
                activeForce.AffectedArea = tempVector;
            }
        }

        private void endTextBox_TextChanged(object sender, EventArgs e)
        {
            double tempValue;
            if (!double.TryParse(endTextBox.Text, out tempValue))
            {
                endTextBox.Text = activeForce.AffectedArea.YValue.ToString();
            }
            else
            {
                Vector2 tempVector = new Vector2();
                tempVector.XValue = activeForce.AffectedArea.XValue;
                tempVector.YValue = tempValue;
                activeForce.AffectedArea = tempVector;
            }
        }

        private void worldForceCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            activeForce.WorldForce = worldForceCheckBox.Checked;

            if (worldForceCheckBox.Checked)
            {
                beggingTextBox.Text = "0";
                beggingTextBox.Enabled = false;
                endTextBox.Text = "0";
                endTextBox.Enabled = false;
            }
            else
            {
                beggingTextBox.Enabled = true;
                endTextBox.Enabled = true;
            }
        }

        private void activeCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            activeForce.Active = activeCheckBox.Checked;
        }

        private void deleteForceButton_Click(object sender, EventArgs e)
        {
            List<Engine.Force2> tempForce = new List<Engine.Force2>();

            for (int i = 0; i < _forces.Count; i++)
            {
                if (_forces[i].Name != forceListBox.SelectedItem.ToString())
                    tempForce.Add(_forces[i]);
            }

            _forces = tempForce;

            UpdateForceList();
        }
        #endregion

        #region Report Tab methods
        private void addReportButton_Click(object sender, EventArgs e)
        {

            List<string> tempObjectNameList = new List<string>();
            List<string> tempReportNameList = new List<string>();
            foreach (Engine.PhysicsObject2 pObject in _objects)
            {
                bool reportAlreadyCreated = false;
                foreach (Reports.ReportSettings report in _reports)
                {
                    if (report.ObjectName == pObject.Name)
                        reportAlreadyCreated = true;
                }

                if (!reportAlreadyCreated)
                    tempObjectNameList.Add(pObject.Name);
            }

            AddReportForm tempForm = new AddReportForm(tempObjectNameList);
            tempForm.ShowDialog(this, new Delegates.modifySimSettings(AddReport));
        }

        private void AddReport(object reportToAdd)
        {
            _reports.Add((Reports.ReportSettings)reportToAdd);

            UpdateReportList();
        }

        private void UpdateReportList()
        {
            List<string> reportNameList = new List<string>();

            foreach (Reports.ReportSettings report in _reports)
            {
                reportNameList.Add(report.ObjectName);
            }

            reportListBox.Items.Clear();
            reportListBox.Items.AddRange(reportNameList.ToArray());
        }

        private void reportListBox_SelectedIndexChanged(object sender, EventArgs e)
        {
            Reports.ReportSettings tempReport = new Reports.ReportSettings();

            for (int i = 0; i < _reports.Count; i++)
            {
                if (_reports[i].ObjectName == reportListBox.SelectedItem.ToString())
                    tempReport = _reports[i];
                else if (_reports[i].ObjectName == activeReport.ObjectName)
                    _reports[i] = activeReport;
            }

            activeReport = tempReport;

            reportObjectTextBox.Text = tempReport.ObjectName;
            recordCollisionCountCheckBox.Checked = tempReport.RecordCollisionCount;
            recordObjectsCollidedWithCheckBox.Checked = tempReport.RecordObjectsCollideAgainst;
            recordPositionCheckBox.Checked = tempReport.RecordPosition;
            recordVelocityCheckBox.Checked = tempReport.RecordVelocity;
        }

        private void recordVelocityCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            activeReport.RecordVelocity = recordVelocityCheckBox.Checked;
        }

        private void recordPositionCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            activeReport.RecordPosition = recordPositionCheckBox.Checked;
        }

        private void recordCollisionCountCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            activeReport.RecordCollisionCount = recordCollisionCountCheckBox.Checked;
        }

        private void recordObjectsCollidedWithCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            activeReport.RecordObjectsCollideAgainst = recordObjectsCollidedWithCheckBox.Checked;
        }

        private void deleteReportButton_Click(object sender, EventArgs e)
        {
            List<Reports.ReportSettings> tempReports = new List<Reports.ReportSettings>();

            for (int i = 0; i < _reports.Count; i++)
            {
                if (_reports[i].ObjectName != reportListBox.SelectedItem.ToString())
                    tempReports.Add(_reports[i]);
            }

            _reports = tempReports;

            UpdateReportList();
        }
        #endregion

        #region Settings Tab methods
        private void selecetFolderButton_Click(object sender, EventArgs e)
        {
            selectFolderDialog.ShowDialog();
            filePathTextBox.Text = selectFolderDialog.SelectedPath;
        }

        private void realTimeElapseCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            if (realTimeElapseCheckBox.Checked)
            {
                realtimeElapseTime.Enabled = true;
            }
            else
            {
                realtimeElapseTime.Enabled = false;
            }
        }

        private void simTimeCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            if (simTimeCheckBox.Checked)
            {
                simulationElapseTime.Enabled = true;
            }
            else
            {
                simulationElapseTime.Enabled = false;
            }
        }

        private void velocityCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            if (velocityCheckBox.Checked)
            {
                vkXTextBox.Enabled = true;
                vkYTextBox.Enabled = true;
            }
            else
            {
                vkXTextBox.Enabled = false;
                vkXTextBox.Text = "0";
                vkYTextBox.Enabled = false;
                vkYTextBox.Text = "0";
            }
        }

        private void xAxisLocation_CheckedChanged(object sender, EventArgs e)
        {
            if (xAxisLocation.Checked)
            {
                xAxisTextBox.Enabled = true;
            }
            else
            {
                xAxisTextBox.Enabled = false;
                xAxisTextBox.Text = "0";
            }
        }

        private void positionCheckBox_CheckedChanged(object sender, EventArgs e)
        {
            if (positionCheckBox.Checked)
            {
                pkXTextBox.Enabled = true;
                pkYTextBox.Enabled = true;
            }
            else
            {
                pkXTextBox.Enabled = false;
                pkXTextBox.Text = "0";
                pkYTextBox.Enabled = false;
                pkYTextBox.Text = "0";
            }
        }

        private void yAxisLocation_CheckedChanged(object sender, EventArgs e)
        {
            if (yAxisLocation.Checked)
            {
                yAxisTextBox.Enabled = true;
            }
            else
            {
                yAxisTextBox.Enabled = false;
                yAxisTextBox.Text = "0";
            }
        }
        #endregion

        #region Menu Items methods
        private void runSimulationButton_Click(object sender, EventArgs e)
        {
            DialogResult result = MessageBox.Show("Are you sure that you would like to start the simulation?");
            if (result == System.Windows.Forms.DialogResult.OK)
            {
                if (ValidateForm()) // <-- most hated method
                {
                    Engine.SimulationSettings simSettings = new Engine.SimulationSettings();

                    simSettings.FilePath = GetFilePath();

                    simSettings.Force = _forces;
                    foreach (PhysicsObject2 pObject in _objects)
                    {
                        if (pObject.Alive)
                            simSettings.Objects.Add(pObject);
                    }
                    
                    List<Reports.Report> tempReports = new List<Reports.Report>();
                    foreach (Reports.ReportSettings report in _reports)
                    {
                        tempReports.Add(new Reports.Report(report, new Reports.ReportData()));
                    }
                    simSettings.Reports = tempReports;

                    simSettings.RunInLightMode = runInLightMode.Checked;
                    simSettings.StepValue = float.Parse(stepValueTextBox.Text);

                    /*Creates the kill condition settings*/
                    Engine.KillCondition kill = new Engine.KillCondition();
                    kill.EndAfterRealWorldTimeElapse = realTimeElapseCheckBox.Checked;
                    kill.EndAfterSimulationElapsedTime = simTimeCheckBox.Checked;
                    kill.EndAtVector = positionCheckBox.Checked;
                    kill.EndAtVelocity = velocityCheckBox.Checked;
                    kill.EndAtXCoord = xAxisLocation.Checked;
                    kill.EndAtYCoord = yAxisLocation.Checked;
                    
                    if (kill.EndAtVector)
                    {
                        kill.EndVector = new Engine.Vector2(double.Parse(pkXTextBox.Text), double.Parse(pkYTextBox.Text));
                    }
                    else
                    {
                        kill.EndVector = Engine.Vector2.Zero;
                    }
                    if (kill.EndAtVelocity)
                    {
                        kill.EndVelocity = new Engine.Vector2(double.Parse(vkXTextBox.Text), double.Parse(vkYTextBox.Text));
                    }
                    else
                    {
                        kill.EndVelocity = Engine.Vector2.Zero;
                    }
                    if (kill.EndAtXCoord)
                    {
                        kill.EndXCoord = double.Parse(xAxisTextBox.Text);
                    }
                    else
                    {
                        kill.EndXCoord = 0;
                    }
                    if (kill.EndAtYCoord)
                    {
                        kill.EndYCoord = double.Parse(yAxisTextBox.Text);
                    }
                    else
                    {
                        kill.EndYCoord = 0;
                    }
                    if (kill.EndAtXCoord || kill.EndAtYCoord || kill.EndAtVelocity || kill.EndAtVector)
                    {
                        kill.NameOfObjectBeingMonitored = killObjectListBox.SelectedItem.ToString();
                    }
                    else
                    {
                        kill.NameOfObjectBeingMonitored = "";
                    }
                    if (kill.EndAfterRealWorldTimeElapse)
                    {
                        kill.RealWorldElapse = ExtractTimeSpan(realtimeElapseTime.Text);
                    }
                    if (kill.EndAfterSimulationElapsedTime)
                    {
                        kill.SimulationElapsedTime = ExtractTimeSpan(simulationElapseTime.Text);
                    }

                    simSettings.Kill = kill;
                    Engine.Simulator simulator = new Engine.Simulator();
                    simulator.StartSimulation(simSettings);
                }

                else
                {
                    MessageBox.Show("The form is not fill out correctly. " +
                        "Please make sure that you only use letters in the correct fields. " +
                        "Once you have corrected the mistakes try resubmit the form");
                }
            }
        }

        private bool ValidateForm()
        {
            bool valideForm = true;
            double tempValue;

            if (!double.TryParse(pkXTextBox.Text, out tempValue))
                valideForm = false;
            else if (!double.TryParse(pkYTextBox.Text, out tempValue))
                valideForm = false;
            else if (!double.TryParse(vkXTextBox.Text, out tempValue))
                valideForm = false;
            else if (!double.TryParse(vkYTextBox.Text, out tempValue))
                valideForm = false;
            else if (!double.TryParse(xAxisTextBox.Text, out tempValue))
                valideForm = false;
            else if (!double.TryParse(yAxisTextBox.Text, out tempValue))
                valideForm = false;
            else if (!double.TryParse(stepValueTextBox.Text, out tempValue))
                valideForm = false;
            else if (tempValue <= 0)
                valideForm = false;

            return valideForm;
        }

        private TimeSpan ExtractTimeSpan(string text)
        {
            int hours, minutes, seconds, milliseconds = 0;
            text = text.Replace(":", "");

            string tempString;

            tempString = text.Substring(1, 2);
            hours = int.Parse(tempString);

            tempString = text.Substring(3, 2);
            minutes = int.Parse(tempString);

            tempString = text.Substring(5, 2);
            seconds = int.Parse(tempString);

            tempString = text.Substring(7, 3);
            milliseconds = int.Parse(tempString);

            return new TimeSpan(0, hours, minutes, seconds, milliseconds);
        }

        private string GetFilePath()
        {
            string tempFileName = fileNameTextBox.Text;

            while (System.IO.File.Exists(System.IO.Path.Combine(filePathTextBox.Text, tempFileName + ".csv")))
            {
                tempFileName += "_1";
            }

            return System.IO.Path.Combine(filePathTextBox.Text, tempFileName + ".csv");
        }

        private void exitMenuItem_Click(object sender, EventArgs e)
        {
            Close();
        }

        private void resetMenuItem_Click(object sender, EventArgs e)
        {
            _forces = new List<Engine.Force2>();
            _objects = new List<Engine.PhysicsObject2>();
            _reports = new List<Reports.ReportSettings>();            

            UpdateForceList();
            UpdateObjectList();
            UpdateReportList();

            /*Resetting objects tab*/
            objectAliveCheckBox.Checked = false;
            objectNameTextBox.Text = "";
            objectMassTextBox.Text = "0";
            objectXVelocityTextBox.Text = "0";
            objectYVelocityTextBox.Text = "0";
            objectXPositionTextBox.Text = "0";
            objectYPositionTextBox.Text = "0";
            activeObject = new Engine.PhysicsObject2();

            /*Resetting forces tab*/
            forceNameTextBox.Text = "";
            worldForceCheckBox.Checked = false;
            activeCheckBox.Checked = false;
            xAccelerationTextBox.Text = "0";
            yAccelerationLabel.Text = "0";
            beggingTextBox.Text = "0";
            endTextBox.Text = "0";
            activeForce = new Engine.Force2();

            /*Resetting reports tab*/
            reportObjectTextBox.Text = "";
            recordCollisionCountCheckBox.Checked = false;
            recordObjectsCollidedWithCheckBox.Checked = false;
            recordPositionCheckBox.Checked = false;
            recordVelocityCheckBox.Checked = false;
            
            /*Resetting settings tab*/
            filePathTextBox.Text = "";
            fileNameTextBox.Text = "";
            stepValueTextBox.Text = "0";
            runInLightMode.Checked = false;
            realTimeElapseCheckBox.Checked = false;
            simTimeCheckBox.Checked = false;

            velocityCheckBox.Checked = false;
            positionCheckBox.Checked = false;
            xAxisLocation.Checked = false;
            yAxisLocation.Checked = false;

        }

        private void viewHelpToolStripMenuItem_Click(object sender, EventArgs e)
        {
            SendKeys.Send("{F1}");
        }

        private void aboutMenuItem_Click(object sender, EventArgs e)
        {
            AboutForm tempForm = new AboutForm();
            tempForm.Show(this);
        }
        #endregion

    }
}
