﻿#region License Informtion
/* This program simulates objects path of motion.
 * Copyright (C) 2010  Timothy Eck II
 * 
 * Physics Simulator is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; version 2 of the License.
 * 
 * Physics Simulator is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.*/
#endregion
using System;
using System.Text;
using System.Collections.Generic;
using System.Linq;
using System.IO;
using System.Threading;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using PhysicsSimulator.Reports;
using PhysicsSimulator.Engine;

namespace PhysicsSimulator.Tests
{
    /// <summary>
    /// Summary description for ReportSpeedTest
    /// </summary>
    [TestClass]
    public class ReportSpeedTest
    {
        public ReportSpeedTest()
        {
            //
            // TODO: Add constructor logic here
            //
        }

        private TestContext testContextInstance;

        /// <summary>
        ///Gets or sets the test context which provides
        ///information about and functionality for the current test run.
        ///</summary>
        public TestContext TestContext
        {
            get
            {
                return testContextInstance;
            }
            set
            {
                testContextInstance = value;
            }
        }

        #region Additional test attributes
        //
        // You can use the following additional attributes as you write your tests:
        //
        // Use ClassInitialize to run code before running the first test in the class
        // [ClassInitialize()]
        // public static void MyClassInitialize(TestContext testContext) { }
        //
        // Use ClassCleanup to run code after all tests in a class have run
        // [ClassCleanup()]
        // public static void MyClassCleanup() { }
        //
        // Use TestInitialize to run code before running each test 
        // [TestInitialize()]
        // public void MyTestInitialize() { }
        //
        // Use TestCleanup to run code after each test has run
        // [TestCleanup()]
        // public void MyTestCleanup() { }
        //
        #endregion

        [TestMethod]
        public void TestSpeedofReportGeneration()
        {
            System.Diagnostics.Stopwatch sw1 = new System.Diagnostics.Stopwatch();
            System.Diagnostics.Stopwatch sw2 = new System.Diagnostics.Stopwatch();

            Reports.ReportGenerator oldGenerator = new ReportGenerator();
            NewReportGenerator newGenerator = new NewReportGenerator();

            // Report Information
            Report report = new Report();
            SimulationReport simReport = new SimulationReport();
            string filePath = @"C:\Users\nevrforget1\Desktop\SimulationReports\tempReport.csv";

            simReport.NumberOfForces = 2;
            simReport.NumberOfFramesCalculated = 20000;
            simReport.NumberOfObjects = 25;
            simReport.SimTime = 25623.00215f;
            simReport.TimeRequiredToSimulate = new TimeSpan(0, 52, 12);

            ReportSettings Settings = new ReportSettings();
            Settings.ObjectName =  "hello";
            Settings.RecordCollisionCount = true;
            Settings.RecordObjectsCollideAgainst = true;
            Settings.RecordPosition = true;
            Settings.RecordVelocity = true;
            report.Settings = Settings;

            ReportData Data = new ReportData();
            Data.ObjectName = "hello";
            Data.CollisionCount = 20;
            Data.ObjectsCollidedWith = new List<string>(){"Hello","Hello","Hello","Hello","Hello","Hello","Hello","Hello",
                "Hello","Hello","Hello","Hello","Hello","Hello","Hello","Hello","Hello","Hello","Hello","Hello","Hello","Hello",
                "Hello","Hello","Hello","Hello","Hello","Hello","Hello","Hello","Hello","Hello"};
            for (int i = 0; i < 100000; i++)
            {
                Data.Position.Add(new Vector2(i));
                Data.Velocity.Add(new Vector2(i));
            }
            report.Data = Data;

            sw1.Start();
            oldGenerator.GenerateCompleteReport(report, simReport, filePath);
            sw1.Stop();

            filePath = @"C:\Users\nevrforget1\Desktop\SimulationReports\tempReport_1.csv";
            sw2.Start();
            newGenerator.NewAlgorithm(report,simReport,filePath);
            sw2.Stop();

            FileStream fs = new FileStream(@"C:\Users\nevrforget1\Desktop\SimulationReports\testReport.txt", FileMode.Create, FileAccess.Write);
            StreamWriter writer = new StreamWriter(fs);
            writer.WriteLine(sw1.Elapsed);
            writer.WriteLine(sw2.Elapsed);
            writer.Close();

            Assert.IsTrue(sw2.Elapsed < sw1.Elapsed, "The new algorithm is not faster");
        }

        private class NewReportGenerator
        {
            string[] reportComponents = new string[4];

            public void NewAlgorithm(Report report, SimulationReport simReport, string filePath)
            {
                /* 0 = header and simulation information
                 * 1 = collision information
                 * 2 = velocity information
                 * 3 = position information */

                /*Threading check*/
                bool thread;
                if (report.Data.Position.Count > 1000 || report.Data.Velocity.Count > 1000
                    || report.Data.CollisionCount>1000 && Environment.ProcessorCount > 1)
                    thread = true;
                else
                    thread = false;

                reportComponents[0] += "Report Generated on :," + DateTime.Now + "\n";

                /*Simulation Data*/
                reportComponents[0] += "Number of objects:," + simReport.NumberOfObjects + "\n";
                reportComponents[0] += "Number of forces:," + simReport.NumberOfForces + "\n";
                reportComponents[0] += "Time required to simulate:," + simReport.TimeRequiredToSimulate + "\n";
                reportComponents[0] += "Time simulation elapse time:," + simReport.SimTime + "\n";
                reportComponents[0] += "Frames calculated:," + simReport.NumberOfFramesCalculated + "\n";

                if (thread)
                {
                    Thread collisionDataThread = new Thread(new ParameterizedThreadStart(BuildCollision));
                    collisionDataThread.Name = "Collision Data Thread";

                    Thread velocityDataThread = new Thread(new ParameterizedThreadStart(BuildVelocity));
                    velocityDataThread.Name = "Velocity Data Thread";

                    Thread positionDataThread = new Thread(new ParameterizedThreadStart(BuildPosition));
                    positionDataThread.Name = "Position Data Thread";

                    List<Report> tempList = new List<Report>() { report };
                    collisionDataThread.Start(tempList);
                    velocityDataThread.Start(tempList);
                    positionDataThread.Start(tempList);

                    while (collisionDataThread.IsAlive || positionDataThread.IsAlive || velocityDataThread.IsAlive) { }
                }
                else
                {
                    List<Report> tempList = new List<Report>() { report };
                    BuildCollision(tempList);
                    BuildVelocity(tempList);
                    BuildPosition(tempList);
                }
                
                WriteToFile(filePath);
            }

            private void BuildCollision(object parameters)
            {
                List<Report> reports = (List<Report>)parameters;

                reportComponents[1] += "Collision data\n";
                foreach (Report report in reports)
                {
                    if (report.Settings.RecordCollisionCount || report.Settings.RecordObjectsCollideAgainst)
                    {
                        string collisionInfo = "";
                        collisionInfo += report.Data.ObjectName + "\n";

                        collisionInfo += report.Data.CollisionCount + "\n";
                        collisionInfo += "Objects Collided With:,";

                        if (report.Data.ObjectsCollidedWith.Count > 0)

                            foreach (string name in report.Data.ObjectsCollidedWith)
                            {
                                collisionInfo += name + ",";
                            }

                        else
                        {
                            collisionInfo += "none";
                        }

                        reportComponents[1] += collisionInfo + "\n";
                    }
                    else
                    {
                        reportComponents[1] += "N/A\n";
                    }
                }
            }

            private void BuildVelocity(object parameters)
            {
                List<Report> reports = (List<Report>)parameters;
                              
                reportComponents[2] += "Velocity Data\n";

                foreach (Report report in reports)
                {
                    if (report.Settings.RecordPosition)
                    {
                        string velocityInfo = "";
                        velocityInfo += report.Data.ObjectName + "\n";

                        string[] velocityComponents = new string[2];
                        for (int i = 0; i < report.Data.Velocity.Count; i++)
                        {
                            velocityComponents[0] += report.Data.Velocity[i].XValue + ",";
                            velocityComponents[1] += report.Data.Velocity[i].YValue + ",";
                        }

                        velocityInfo += "X:," + velocityComponents[0] + "\n";
                        velocityInfo += "Y:," + velocityComponents[1] + "\n";

                        reportComponents[2] += velocityInfo + "\n";
                    }
                }
            }

            private void BuildPosition(object parameters)
            {
                List<Report> reports = (List<Report>)parameters;
                reportComponents[3] += "Position Data\n";

                foreach (Report report in reports)
                {
                    if (report.Settings.RecordPosition)
                    {
                        string positionInfo = "";
                        positionInfo += report.Data.ObjectName + "\n";

                        string[] positionComponents = new string[2];

                        for (int i = 0; i < report.Data.Position.Count; i++)
                        {
                            positionComponents[0] += report.Data.Position[i].XValue + ",";
                            positionComponents[1] += report.Data.Position[i].YValue + ",";
                        }

                        positionInfo += "X:," + positionComponents[0] + "\n";
                        positionInfo += "Y:," + positionComponents[1] + "\n";

                        reportComponents[3] += positionInfo + "\n";
                    }
                }
            }

            private void WriteToFile(string filePath)
            {
                /* Error Code 0001 = There is an error encountered while trying to gain access to the file or writing to the file.
                 *                   Make sure that no other applications are using the file.
                 * Error Code 0002 = There was an unknown error encountered while trying to gain access to the file or writing to the file.
                 *                   
                 */
                try
                {
                    FileStream fs = new FileStream(filePath, FileMode.OpenOrCreate, FileAccess.Write);
                    StreamWriter writer = new StreamWriter(fs);
                    writer.Write(reportComponents[0]);
                    writer.Write(reportComponents[1]);
                    writer.Write(reportComponents[2]);
                    writer.Write(reportComponents[3]);
                    writer.Close();
                }
                catch (IOException e)
                {
                    System.Windows.Forms.DialogResult result = System.Windows.Forms.MessageBox.Show(
                        "Error Code: 0001\nThere was an error creating or writing to" +
                        "the file and the report can not be created.", "Error Code 0001", 
                        System.Windows.Forms.MessageBoxButtons.RetryCancel);
               
                    if(result == System.Windows.Forms.DialogResult.Retry)
                        WriteToFile(filePath);
                }
                catch (Exception e)
                {
                    System.Windows.Forms.DialogResult result = System.Windows.Forms.MessageBox.Show(
                        "Error Code: 0002\nThere was an unknown error creating or writing to" +
                        "the file and the report can not be created.", "Error Code 0002",
                        System.Windows.Forms.MessageBoxButtons.RetryCancel);

                    if (result == System.Windows.Forms.DialogResult.Retry)
                        WriteToFile(filePath);              
                }
            }
        } 
    }
}
