﻿#region License Informtion
/* This program simulates objects path of motion.
 * Copyright (C) 2010  Timothy Eck II
 * 
 * Physics Simulator is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; version 2 of the License.
 * 
 * Physics Simulator is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.*/
#endregion
using System;
using System.Collections.Generic;
using System.IO;

namespace PhysicsSimulator.Reports
{
    /// <summary>
    /// Creates and persists reports.
    /// </summary>
    public struct Report
    {
        ReportData _data;
        ReportSettings _settings;

        #region Properties
        /// <summary>
        /// Gets or sets the data for the report.
        /// </summary>
        /// <value>The report data.</value>
        public ReportData Data
        {
            get { return _data; }
            set { _data = value; }
        }

        /// <summary>
        /// Gets or sets the settings for the report.
        /// </summary>
        /// <value>The report settings.</value>
        public ReportSettings Settings
        {
            get { return _settings; }
            set { _settings = value; }
        }
        #endregion

        /// <summary>
        /// Initializes a new instance of the <see cref="Report"/> struct.
        /// </summary>
        /// <param name="settings">The settings for the report.</param>
        /// <param name="data">The data for the report.</param>
        public Report(ReportSettings settings = new ReportSettings(), ReportData data = null)
        {
            _settings = settings;

            if (data == null)
            {
                _data = new ReportData();
            }
            else
            {
                _data = data;
            }
        }
    }
}
