﻿#region License Informtion
/* This program simulates objects path of motion.
 * Copyright (C) 2010  Timothy Eck II
 * 
 * Physics Simulator is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; version 2 of the License.
 * 
 * Physics Simulator is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.*/
#endregion
using System;
using System.Collections.Generic;
using PhysicsSimulator.Engine;

namespace PhysicsSimulator.Reports
{
    /// <summary>
    /// Data to be used in a report on an object.
    /// </summary>
    public class ReportData
    {
        private string _objectName;
        private List<Vector2> _velocity;
        private List<Vector2> _position;
        private long _collisionCount;
        private List<string> _objectsCollidedWith;

        #region Properties
        /// <summary>
        /// Gets or sets the name of the object.
        /// </summary>
        /// <value>The name of the object.</value>
        public string ObjectName
        {
            get { return _objectName; }
            set { _objectName = value; }
        }

        /// <summary>
        /// Gets or sets the velocity.
        /// </summary>
        /// <value>The velocity.</value>
        public List<Vector2> Velocity
        {
            get { return _velocity; }
            set { _velocity = value; }
        }

        /// <summary>
        /// Gets or sets the position.
        /// </summary>
        /// <value>The position.</value>
        public List<Vector2> Position
        {
            get { return _position; }
            set { _position = value; }
        }

        /// <summary>
        /// Gets or sets the collision count.
        /// </summary>
        /// <value>The collision count.</value>
        public long CollisionCount
        {
            get { return _collisionCount; }
            set { _collisionCount = value; }
        }

        /// <summary>
        /// Gets or sets the objects collided with.
        /// </summary>
        /// <value>The objects collided with.</value>
        public List<string> ObjectsCollidedWith
        {
            get { return _objectsCollidedWith; }
            set { _objectsCollidedWith = value; }
        }
        #endregion

        /// <summary>
        /// Initializes a new instance of the <see cref="ReportData"/> class.
        /// </summary>
        /// <param name="objectName">Name of the object the report is on.</param>
        /// <param name="velocity">The velocity of the object.</param>
        /// <param name="position">The position of the object.</param>
        /// <param name="collisionCount">The collision count.</param>
        /// <param name="objectsCollidedWith">The objects collided with.</param>
        public ReportData(string objectName = "ne ner ne ner", List<Vector2> velocity = null, List<Vector2> position = null,
            long collisionCount = 0, List<string> objectsCollidedWith = null)
        {
            _objectName = objectName;
            if (velocity == null)
            {
                _velocity = new List<Vector2>();
            }
            else
            {
                _velocity = velocity;
            }

            if (position == null)
            {
                _position = new List<Vector2>();
            }
            else
            {
                _position = position;
            }

            _collisionCount = collisionCount;

            if (objectsCollidedWith == null)
            {
                _objectsCollidedWith = new List<string>();
            }
            else
            {
                _objectsCollidedWith = objectsCollidedWith;
            }
        }
    }
}
