﻿#region License Informtion
/* This program simulates objects path of motion.
 * Copyright (C) 2010  Timothy Eck II
 * 
 * Physics Simulator is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; version 2 of the License.
 * 
 * Physics Simulator is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.*/
#endregion
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace PhysicsSimulator.Reports
{
    /// <summary>
    /// Contains fields to specify the data to record to generate reports
    /// </summary>
    public struct ReportSettings
    {
        string _objectName;
        bool _recordVelocity;
        bool _recordPosition;
        bool _recordCollisionCount;
        bool _recordObjectsCollidedWith;

        #region Properties
        /// <summary>
        /// Gets or sets the name of the object.
        /// </summary>
        /// <value>The name of the object.</value>
        public string ObjectName
        {
            get { return _objectName; }
            set { _objectName = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether to record velocity.
        /// </summary>
        /// <value><c>true</c> if [record velocity]; otherwise, <c>false</c>.</value>
        public bool RecordVelocity
        {
            get { return _recordVelocity; }
            set { _recordVelocity = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether to record position.
        /// </summary>
        /// <value><c>true</c> if [record position]; otherwise, <c>false</c>.</value>
        public bool RecordPosition
        {
            get { return _recordPosition; }
            set { _recordPosition = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether to record collision count.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if [record collision count]; otherwise, <c>false</c>.
        /// </value>
        public bool RecordCollisionCount
        {
            get { return _recordCollisionCount; }
            set { _recordCollisionCount = value; }
        }

        /// <summary>
        /// Gets or sets a value indicating whether to record objects collide against.
        /// </summary>
        /// <value>
        /// 	<c>true</c> if [record objects collide against]; otherwise, <c>false</c>.
        /// </value>
        public bool RecordObjectsCollideAgainst
        {
            get { return _recordObjectsCollidedWith; }
            set { _recordObjectsCollidedWith = value; }
        }
        #endregion

        /// <summary>
        /// Initializes a new instance of the <see cref="ReportSettings"/> struct.
        /// </summary>
        /// <param name="RecordVelocity">if set to <c>true</c> [record velocity].</param>
        /// <param name="RecordPosition">if set to <c>true</c> [record position].</param>
        /// <param name="RecordCollisionCount">if set to <c>true</c> [record collision count].</param>
        /// <param name="RecordObjectsCollidedWith">if set to <c>true</c> [record objects collided with].</param>
        public ReportSettings(string objectName = ":{)", bool RecordVelocity = true, bool RecordPosition = true,
            bool RecordCollisionCount = false, bool RecordObjectsCollidedWith = false)
        {
            _objectName = objectName;
            _recordVelocity = RecordVelocity;
            _recordPosition = RecordPosition;
            _recordCollisionCount = RecordCollisionCount;
            _recordObjectsCollidedWith = RecordObjectsCollidedWith;
        }
    }
}
