﻿#region License Informtion
/* This program simulates objects path of motion.
 * Copyright (C) 2010  Timothy Eck II
 * 
 * Physics Simulator is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by 
 * the Free Software Foundation; version 2 of the License.
 * 
 * Physics Simulator is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program; if not, write to the Free Software Foundation, Inc.,
 * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.*/
#endregion
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace PhysicsSimulator.Reports
{
    /// <summary>
    /// Used to generate a report on the simulation engine stats.
    /// </summary>
    public struct SimulationReport
    {
        int _numberOfObjects;
        int _numberOfForces;
        TimeSpan _timeRequiredToSimulate;
        int _numberOfFramesCalculated;
        float _simTime;

        #region Properties
        /// <summary>
        /// Gets or sets the number of objects.
        /// </summary>
        /// <value>The number of objects.</value>
        public int NumberOfObjects
        {
            get { return _numberOfObjects; }
            set { _numberOfObjects = value; }
        }

        /// <summary>
        /// Gets or sets the number of forces.
        /// </summary>
        /// <value>The number of forces.</value>
        public int NumberOfForces
        {
            get { return _numberOfForces; }
            set { _numberOfForces = value; }
        }

        /// <summary>
        /// Gets or sets the time required to simulate.
        /// </summary>
        /// <value>The time required to simulate.</value>
        public TimeSpan TimeRequiredToSimulate
        {
            get { return _timeRequiredToSimulate; }
            set { _timeRequiredToSimulate = value; }
        }

        /// <summary>
        /// Gets or sets the number of frames calculated.
        /// </summary>
        /// <value>The number of frames calculated.</value>
        public int NumberOfFramesCalculated
        {
            get { return _numberOfFramesCalculated; }
            set { _numberOfFramesCalculated = value; }
        }

        /// <summary>
        /// Gets or sets the simulation time.
        /// </summary>
        /// <value>The sim time.</value>
        public float SimTime
        {
            get { return _simTime; }
            set { _simTime = value; }
        }
        #endregion
    }
}
